<?php
/**
 * Created by PhpStorm.
 * User: francismararaujo
 * Date: 23/10/14
 * Time: 17:07
 */

namespace Service;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Method;
use \Util\CRUD;
use \Service\JWT;

class LoginService{

	const UPDATE_USER_PASSWORD = "UPDATE OPERADOR SET CDSENHAOPERWEB = :CDSENHAOPERWEB WHERE DSEMAILOPER = :DSEMAILOPER";
	const USER_BY_MAIL = "SELECT NRORG, CDOPERADOR, DSEMAILOPER, NMOPERADOR, IDOPERATIVO, CDSENHOPER, CDSENHAOPERWEB, NRESTRUTTRAB, NRORGTRAB FROM OPERADOR WHERE DSEMAILOPER = :DSEMAILOPER";
	const UNITS = "SELECT F.NMFILIAL,
		  F.CDEMPRESA,
		  F.CDFILIAL,
		  NVL(F.CDFILCENTPME, F.CDFILIAL) CDFILLANCA,
		  F.NRORG,
		  DECODE(F.CDFILCENTCMP, NULL, F.CDFILIAL, F.CDFILCENTCMP) AS CDFILCENTCMP,
		  DECODE(F.IDFILCENTPME, 'S', F.CDFILIAL, 'N', F.CDFILCENTPME, NULL) AS CDFILCENTPME
		  FROM FILIOPER FO JOIN FILIAL F ON FO.CDFILIAL = F.CDFILIAL
							AND FO.NRORG = F.NRORG
							WHERE FO.CDOPERADOR = :CDOPERADOR
							ORDER BY F.CDFILIAL";

	const OPERADOR = "SELECT NRORG, CDOPERADOR, CDFILIALSELECIONADA FROM OPERADOR WHERE CDOPERADOR = :CDOPERADOR";

    protected $entityManager;
    protected $environment;
    protected $connection;
    protected $session;
    protected $CRUD;
    protected $user = array();

    public function __construct($entityManager, $session, CRUD $CRUD) {

        $this->entityManager = $entityManager;
        $this->session = $session;
        $this->connection = $entityManager->getConnection();
        $this->CRUD = $CRUD;
    }

    private function initUnits() {

        $params = array(
            'CDOPERADOR' => $this->user['auth']['CDOPERADOR']
        );

        $units = $this->CRUD->read(self::UNITS, $params);

        $params = array(
            'CDOPERADOR' => $this->user['auth']['CDOPERADOR']
        );
        $operator = $this->CRUD->read(self::OPERADOR, $params);

        $this->user['units'] = array();

        $this->user['auth']['CDFILIAL'] = "";
        $this->user['auth']['NMFILIAL'] = "";
        $this->user['auth']['CDFILLANCA'] = "";

        if(count($operator) !== 0){
            foreach ($units as $unit) {

                if($unit['CDFILIAL'] == $operator[0]['CDFILIALSELECIONADA']) {

                    $this->user['auth']['CDFILIAL'] = $unit['CDFILIAL'];
                    $this->user['auth']['NMFILIAL'] = $unit['NMFILIAL'];
                    $this->user['auth']['CDFILLANCA'] = $unit['CDFILLANCA'];

                }
                $this->user['units'][] = $unit;

            }
        }
    }

    private function getCryptoPassword($password) {

        $url = 'https://www.security.teknisa.com/comwebservice/service.asmx?wsdl';

        $options = array(
            'encoding'    => 'ISO-8859-1',
            'trace'       => true,
            'exceptions'  => true,
            'compression' => SOAP_COMPRESSION_ACCEPT | SOAP_COMPRESSION_GZIP,
        );

        $args = array(
            new \SoapVar($password, XSD_STRING, 'string', "http://www.w3.org/2001/XMLSchema")
        );

        $params = array(
            'rdm'    => 'Bib_html.rdmDBGeralHtm',
            'method' => 'GetCriptoPass',
            'args'   => $args,
        );

        try {

            $client = new \SoapClient($url, $options);
            $return = $client->executeCOMMethod($params);
            $cryptoPassword = $return->executeCOMMethodResult;

        }catch (\SoapFault $e) {
            throw new \Exception($e->getMessage());
        }

        return $cryptoPassword;

    }

    private function validateUserPassword($password) {
        if ($this->user['auth']['CDSENHOPER'] &&
            !$this->user['auth']['CDSENHAOPERWEB']) {

            $cryptoPassword = $this->getCryptoPassword($password);
            if($this->user['auth']['CDSENHOPER'] != $cryptoPassword) {
                throw new \Exception("Senha inválida.");
            }

            $params = array(
                'DSEMAILOPER' => $this->user['auth']['DSEMAILOPER'],
                'CDSENHAOPERWEB' => MD5($password)
            );

            $this->CRUD->update(self::UPDATE_USER_PASSWORD, $params);
        } else {

            if($this->user['auth']['CDSENHAOPERWEB'] != MD5($password)) {
                throw new \Exception("Senha inválida.");
            }

        }

    }

    private function initUser($email) {

        $params = array(
            'DSEMAILOPER' => $email
        );
        $user = $this->CRUD->read(self::USER_BY_MAIL, $params);
        if(!$user) {
            throw new \Exception("Operador não está cadastrado.");
        }
        $user = $user[0];
        if($user['IDOPERATIVO'] !== 'A') {
            throw new \Exception("Operador não está ativo.");
        }
        $this->user['auth'] = $user;

    }

    public function getUser($email, $password) {

        $this->initUser($email);
        $this->validateUserPassword($password);
        $this->initUnits();

        $this->session->start();
        $this->session->set('Units',  $this->user['units']);
        $this->session->set('Auth',  $this->user['auth']);

        JWT::unsetSessionCookie("schoolmeals");
        $token = JWT::generateToken($this->user['auth']);
        JWT::setSessionCookie("schoolmeals", $token, 0);

        return $this->user;

    }

}