module.exports = function (grunt) {

	var schoolmeals = {
		js: [
			"bower_components/zh-cache-bypass/src/CacheBypass.js",
            "js/libs/**/*.js",
            "js/util/**/*.js",
            "js/model/**/*.js",
            "js/services/**/*.js",
            "js/controllers/**/*.js"
        ],
		css: ["css/**/*.css"],
	};

	var zeedhi = {
		js: [
			"bower_components/zeedhi-frontend/assets/dist/main.min.js"
		]
	};

	grunt.initConfig({
		concat: {
			css: {
				options: {
					process: function (src, filepath) {
						return '/* FILE: ' + filepath + ' */\n' + src + '\n';
					}
				},
				src: schoolmeals.css,
				dest: 'dist/schoolmeals.css'
			},
			js: {
				options: {
					process: function (src, filepath) {
						return '// FILE: ' + filepath + '\n' + src + '\n';
					}
				},
				src: schoolmeals.js,
				dest: 'dist/schoolmeals.js'
			}
		},
		jshint: {
			all: schoolmeals.js.concat(["GruntFile.js"]),
			options: {
				esversion: 8
			}
		},
		uglify: {
			options: {
				mangle: false,
				compress: false,
				report: 'min',
				// the banner is inserted at the top of the output
				banner: '/*! <%= grunt.template.today("dd-mm-yyyy") %> */\n'
			},
			dist: {
				files: {
					'dist/schoolmeals.min.js': zeedhi.js.concat(schoolmeals.js)
				}
			}
		},
		cssmin: {
			schoolmeals: {
				src: schoolmeals.css,
				dest: 'dist/schoolmeals.min.css'
			},
			zeedhi: {
				src: "bower_components/zeedhi-frontend/assets/css/styles/styles-schoolmeals.css",
				dest: 'bower_components/zeedhi-frontend/assets/css/styles/styles-schoolmeals.min.css'
			}
		},
		watch: {
			pivotal: {
				files: schoolmeals.js.concat(schoolmeals.css),
				tasks: ['jshint', 'cssmin', 'concat']
			}
		},
		clean: {
			zh_compass: ["bower_components/zeedhi-frontend/assets/compass/"],
			zh_css: [
				"bower_components/zeedhi-frontend/assets/css/*.css",
				"bower_components/zeedhi-frontend/assets/css/libs/*.css",
				"bower_components/zeedhi-frontend/assets/css/styles/*.css",
				"!bower_components/zeedhi-frontend/assets/css/.min.css",
				"!bower_components/zeedhi-frontend/assets/css/libs/*.min.css",
				"!bower_components/zeedhi-frontend/assets/css/styles/*.min.css"
			],
			zh_dist: ["bower_components/zeedhi-frontend/assets/dist/"],
			zh_js: ["bower_components/zeedhi-frontend/assets/js/"],
			zh_json: ["bower_components/zeedhi-frontend/assets/json/"],
			zh_runer: ["bower_components/zeedhi-frontend/assets/runer/"],
			zh_specs: ["bower_components/zeedhi-frontend/assets/specs/"],
			sm_css: ["css/"],
			sm_dist: [
				"dist/*",
				"!dist/*.min.js",
				"!dist/*.min.css"
			],
			sm_js: ["js/"],
			sm_specs: ["specs/"]
		},
		buildEnvironment: {
			development: {
				configFile: "./config/devEnvironment.json"
			},
			production: {
				configFile: "./config/prodEnvironment.json"
			},
			test: {
				configFile: "./config/testEnvironment.json"
			},
			srcFolders: ["../backend", "./config", "./"]
		}
	});

	grunt.loadNpmTasks('grunt-contrib-jshint');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-contrib-cssmin');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-watch');
	grunt.loadNpmTasks('grunt-contrib-clean');
	grunt.loadNpmTasks('grunt-zh-environment-builder');

	// Default task.
	grunt.registerTask('default', ['jshint', 'concat', 'buildEnvironment']);
	grunt.registerTask('dist', ['uglify', 'cssmin']);

};